@@ -27,6 +27,9 @@ try:
 except ImportError:
     from io import StringIO
 from os.path import expanduser
+import inspect
+import psutil
+
 
 ###################################################################
 # CLASSES                                                         #
@@ -136,8 +139,6 @@ class tools(object):
         self.docString = docString
         self.logLevel = logLevel
 
-        import psutil
-
         if not distributionName:
             distributionName = projectName
 
@@ -178,6 +179,24 @@ class tools(object):
         except:
             pass
 
+        # GET ADVANCED SETTINGS IF AVAILABLE
+        advs = os.getcwd() + "/rubbish.yaml"
+        level = 0
+        exists = False
+        count = 1
+        while not exists and len(advs) and count < 10:
+            count += 1
+            level -= 1
+            exists = os.path.exists(advs)
+            if not exists:
+                advs = "/".join(inspect.stack()
+                                [1][1].split("/")[:level]) + "/advanced_settings.yaml"
+        if not exists:
+            advs = {}
+        else:
+            with open(advs, 'r') as stream:
+                advs = yaml.load(stream)
+
         if defaultSettingsFile and "settingsFile" not in arguments and "--settings" not in arguments and os.path.exists(os.getenv(
                 "HOME") + "/.config/%(projectName)s/%(projectName)s.yaml" % locals()):
             arguments["settingsFile"] = settingsFile = os.getenv(
@@ -218,7 +237,6 @@ class tools(object):
                     writeFile = codecs.open(
                         settingsFile, encoding='utf-8', mode='w')
 
-                import yaml
                 # GET CONTENT OF YAML FILE AND REPLACE ~ WITH HOME DIRECTORY
                 # PATH
                 with open(settingsFile) as f:
@@ -236,7 +254,6 @@ class tools(object):
                     settings = this
                     arguments["<settingsFile>"] = settingsFile
                 else:
-                    import inspect
                     ds = os.getcwd() + "/rubbish.yaml"
                     level = 0
                     exists = False
@@ -297,18 +314,24 @@ class tools(object):
         else:
             pass
 
+        # FOR SETTINGS FILE PATHS PASSED DIRECTORY VIA THE CL
         if stream is not False:
 
             astream = stream.read()
             home = expanduser("~")
             astream = astream.replace("~/", home + "/")
 
-            import yaml
             if orderedSettings:
                 settings = ordered_load(astream, yaml.SafeLoader)
             else:
                 settings = yaml.load(astream)
 
+        # MERGE ADVANCED SETTINGS AND USER SETTINGS (USER SETTINGS OVERRIDE)
+        if 'settings' not in locals():
+            settings = advs
+        else:
+            settings = {**advs, **settings}
+
         # SETUP LOGGER -- DEFAULT TO CONSOLE LOGGER IF NONE PROVIDED IN
         # SETTINGS
         if 'settings' in locals() and "logging settings" in settings:
@@ -365,13 +388,16 @@ class tools(object):
         # SETUP A DATABASE CONNECTION BASED ON WHAT ARGUMENTS HAVE BEEN PASSED
         dbConn = False
         tunnel = False
-        if ("hostFlag" in locals() and "dbNameFlag" in locals() and hostFlag):
+
+        if ("--host" in arguments and "--dbName" in arguments and arguments["--host"]):
             # SETUP DB CONNECTION
             dbConn = True
             host = arguments["--host"]
             user = arguments["--user"]
             passwd = arguments["--passwd"]
             dbName = arguments["--dbName"]
+            port = False
+
         elif 'settings' in locals() and "database settings" in settings and "host" in settings["database settings"]:
             host = settings["database settings"]["host"]
             user = settings["database settings"]["user"]
